import vega from 'vega';
import vegaLite from 'vega-lite';
import vl from 'vega-lite-api';
import { Handler } from 'vega-tooltip';
import { config } from './config';
import { getData } from './getData';
import { viz } from './viz';

vl.register(vega, vegaLite, {
  view: { renderer: 'svg' }, /* Use svg vs canvas - slows down if there is a lot of data*/
  init: view => { view.tooltip(new Handler().call); } /* Makes tooltip work */
});

const run = async () => {
  const marks = viz
    .data(await getData()) /* Provides data once loaded */
    .width(window.innerWidth) /* Sets to side of window */
    .height(window.innerHeight)
    .autosize({ type: 'fit', contains: 'padding' }) /* Fit in window */
    .config(config); /* Customizes appearance */
  
  document.body.appendChild(await marks.render());
};
run();